import { GetOptions } from "infisical-node/lib/types/InfisicalClient";
import { createInfisicalClient } from "utils";

export let PROXY_SECRET: string;

/**
 * Initialize the secrets from Infisical
 */
export async function initSecrets(token: string) {
  console.log("Initializing secrets...");

  const infisicalClient = createInfisicalClient(token);
  const options: GetOptions = {
    environment: process.env.NODE_ENV === "production" ? "main" : "dev",
    path: "/",
    type: "shared",
  };

  const proxySecret = (await infisicalClient.getSecret("PROXY_SECRET", options))
    .secretValue;

  if (!proxySecret) {
    throw new Error("PROXY_SECRET not set in Infisical");
  }

  PROXY_SECRET = proxySecret;
}
